==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/ActiveUseCheckStmt.h <==
// public class org.dellroad.jc.cgen.ActiveUseCheckStmt

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 20cd8f3a2ec3c3aa org_dellroad_jc_cgen_ActiveUseCheckStmt
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class b3c0d2cd30f6acdd soot_jimple_internal_AbstractStmt
// @dep_class 9bd832fad7d8404f soot_jimple_internal_JInvokeStmt
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_internal_JInvokeStmt

#include "soot/jimple/internal/JInvokeStmt.h"

#ifndef _JC_org_dellroad_jc_cgen_ActiveUseCheckStmt_H_
#define _JC_org_dellroad_jc_cgen_ActiveUseCheckStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_PatchingChain$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_jimple_Stmt$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$sub_refs	_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$sub_nonrefs	_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$refs	_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$refs;
typedef struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$nonrefs	_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$object	_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$object;

typedef struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$fields_struct	_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$fields_struct;
typedef const struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$vmethods	_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$vtable	_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$vtype	_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$vtype;

// Class fields structure
struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$fields_struct {
	struct _jc_java_lang_String$object	*PREFIX;
};
extern _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$fields_struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$class_fields;

// Constructors
extern void _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$method$_init$b4cade978254e10c(_jc_env *, struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$object *, struct _jc_soot_SootClass$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$object *);
extern void _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$method_info$toString$49ce0d4a4e59c2a6;

// Static methods
extern void _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_soot_SootMethod$object *_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$method$getCheckMethod$a8285f7656ad3e74(_jc_env *);
extern struct _jc_java_lang_String$object *_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$method$getClassName$e6f0b1535de06f48(_jc_env *, struct _jc_object *);
extern struct _jc_soot_SootClass$object *_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$method$getSootClass$1c7336aa80687d4f(_jc_env *, struct _jc_object *);
extern void _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$method$insertActiveUseCheck$42c2c369f2ffca85(_jc_env *, struct _jc_soot_PatchingChain$object *, struct _jc_object *, struct _jc_soot_SootClass$object *);
extern jboolean _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$method$isActiveUseCheck$550555849d3f87d9(_jc_env *, struct _jc_object *);

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$object *, struct _jc_object *);
};

// Vtable
struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_jimple_internal_AbstractStmt$vmethods	soot_jimple_internal_AbstractStmt;
	_jc_soot_jimple_internal_JInvokeStmt$vmethods	soot_jimple_internal_JInvokeStmt;
	_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$vmethods	org_dellroad_jc_cgen_ActiveUseCheckStmt;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$refs {
    _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$sub_refs	org_dellroad_jc_cgen_ActiveUseCheckStmt;
    _jc_soot_jimple_internal_JInvokeStmt$sub_refs	soot_jimple_internal_JInvokeStmt;
    _jc_soot_jimple_internal_AbstractStmt$sub_refs	soot_jimple_internal_AbstractStmt;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_jimple_internal_AbstractStmt$sub_nonrefs	soot_jimple_internal_AbstractStmt;
    _jc_soot_jimple_internal_JInvokeStmt$sub_nonrefs	soot_jimple_internal_JInvokeStmt;
    _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$sub_nonrefs	org_dellroad_jc_cgen_ActiveUseCheckStmt;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$object {
	_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$vtype _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_ActiveUseCheckStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_ActiveUseCheckStmt_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/cgen/ActiveUseCheckStmt.h <==
// public class org.dellroad.jc.cgen.ActiveUseCheckStmt

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 20cd8f3a2ec3c3aa org_dellroad_jc_cgen_ActiveUseCheckStmt
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class b3c0d2cd30f6acdd soot_jimple_internal_AbstractStmt
// @dep_class 9bd832fad7d8404f soot_jimple_internal_JInvokeStmt
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_internal_JInvokeStmt

#include "soot/jimple/internal/JInvokeStmt.h"

#ifndef _JC_org_dellroad_jc_cgen_ActiveUseCheckStmt_H_
#define _JC_org_dellroad_jc_cgen_ActiveUseCheckStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_PatchingChain$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_jimple_Stmt$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$sub_refs	_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$sub_nonrefs	_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$refs	_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$refs;
typedef struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$nonrefs	_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$object	_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$object;

typedef struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$fields_struct	_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$fields_struct;
typedef const struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$vmethods	_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$vtable	_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$vtype	_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$vtype;

// Class fields structure
struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$fields_struct {
	struct _jc_java_lang_String$object	*PREFIX;
};
extern _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$fields_struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$class_fields;

// Constructors
extern void _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$method$_init$b4cade978254e10c(_jc_env *, struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$object *, struct _jc_soot_SootClass$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$method_info$toString$49ce0d4a4e59c2a6;

// Static methods
extern void _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_soot_SootMethod$object *_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$method$getCheckMethod$a8285f7656ad3e74(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$method$getClassName$e6f0b1535de06f48(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_soot_SootClass$object *_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$method$getSootClass$1c7336aa80687d4f(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$method$insertActiveUseCheck$42c2c369f2ffca85(_jc_env *, struct _jc_soot_PatchingChain$object *, struct _jc_object *, struct _jc_soot_SootClass$object *) _JC_JCNI_ATTR;
extern jboolean _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$method$isActiveUseCheck$550555849d3f87d9(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_jimple_internal_AbstractStmt$vmethods	soot_jimple_internal_AbstractStmt;
	_jc_soot_jimple_internal_JInvokeStmt$vmethods	soot_jimple_internal_JInvokeStmt;
	_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$vmethods	org_dellroad_jc_cgen_ActiveUseCheckStmt;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$refs {
    _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$sub_refs	org_dellroad_jc_cgen_ActiveUseCheckStmt;
    _jc_soot_jimple_internal_JInvokeStmt$sub_refs	soot_jimple_internal_JInvokeStmt;
    _jc_soot_jimple_internal_AbstractStmt$sub_refs	soot_jimple_internal_AbstractStmt;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_jimple_internal_AbstractStmt$sub_nonrefs	soot_jimple_internal_AbstractStmt;
    _jc_soot_jimple_internal_JInvokeStmt$sub_nonrefs	soot_jimple_internal_JInvokeStmt;
    _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$sub_nonrefs	org_dellroad_jc_cgen_ActiveUseCheckStmt;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$object {
	_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$vtype _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_ActiveUseCheckStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_ActiveUseCheckStmt$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_ActiveUseCheckStmt_H_ */
